Date: prev next · Thread: first prev next last
2011 Archives by date, by thread · List index


CHILDS -> CHILDREN

Careful with this one.  I had to make some manual changes to the
patch file to undo some changes that shouldn't happen.

Mike
From f651d57dbe3ab1450c68357512367d10ad22a8aa Mon Sep 17 00:00:00 2001
From: Michael T. Whiteley <mike@whiteley.org>
Date: Wed, 7 Dec 2011 02:42:29 -0800
Subject: [PATCH] CHILDS -> CHILDREN

---
 basctl/source/basicide/baside2b.cxx                |    4 +-
 dbaccess/source/ui/control/dbtreelistbox.cxx       |    2 +-
 lotuswordpro/source/filter/lwplayoutdef.hxx        |    2 +-
 rsc/doku/feinkonz.43/rsc.sdw                       |  Bin 89277 -> 89279 bytes
 svtools/inc/svtools/svlbox.hxx                     |    6 +-
 svtools/source/contnr/svlbox.cxx                   |    4 +-
 .../accessibility/svxrectctaccessiblecontext.cxx   |   26 ++++++------
 svx/source/inc/svxrectctaccessiblecontext.hxx      |    4 +-
 vcl/source/window/window.cxx                       |   44 ++++++++++----------
 9 files changed, 46 insertions(+), 46 deletions(-)

diff --git a/basctl/source/basicide/baside2b.cxx b/basctl/source/basicide/baside2b.cxx
index 857cec2..9b3ca10 100644
--- a/basctl/source/basicide/baside2b.cxx
+++ b/basctl/source/basicide/baside2b.cxx
@@ -2070,12 +2070,12 @@ void implEnableChildren( SvLBoxEntry* pEntry, bool bEnable )
         pEntry->SetFlags(
             (pEntry->GetFlags() &
             ~(SV_ENTRYFLAG_NO_NODEBMP | SV_ENTRYFLAG_HAD_CHILDREN))
-            | SV_ENTRYFLAG_CHILDS_ON_DEMAND );
+            | SV_ENTRYFLAG_CHILDREN_ON_DEMAND );
     }
     else
     {
         pEntry->SetFlags(
-            (pEntry->GetFlags() & ~(SV_ENTRYFLAG_CHILDS_ON_DEMAND)) );
+            (pEntry->GetFlags() & ~(SV_ENTRYFLAG_CHILDREN_ON_DEMAND)) );
     }
 }
 
diff --git a/dbaccess/source/ui/control/dbtreelistbox.cxx 
b/dbaccess/source/ui/control/dbtreelistbox.cxx
index 858431a..0a177be 100644
--- a/dbaccess/source/ui/control/dbtreelistbox.cxx
+++ b/dbaccess/source/ui/control/dbtreelistbox.cxx
@@ -216,7 +216,7 @@ void DBTreeListBox::MouseButtonDown( const MouseEvent& rMEvt )
 IMPL_LINK(DBTreeListBox, OnResetEntry, SvLBoxEntry*, pEntry)
 {
     // set the flag which allows if the entry can be expanded
-    pEntry->SetFlags( (pEntry->GetFlags() & ~(SV_ENTRYFLAG_NO_NODEBMP | 
SV_ENTRYFLAG_HAD_CHILDREN)) | SV_ENTRYFLAG_CHILDS_ON_DEMAND );
+    pEntry->SetFlags( (pEntry->GetFlags() & ~(SV_ENTRYFLAG_NO_NODEBMP | 
SV_ENTRYFLAG_HAD_CHILDREN)) | SV_ENTRYFLAG_CHILDREN_ON_DEMAND );
     // redraw the entry
     GetModel()->InvalidateEntry( pEntry );
     return 0L;
diff --git a/lotuswordpro/source/filter/lwplayoutdef.hxx 
b/lotuswordpro/source/filter/lwplayoutdef.hxx
index fde3a14..48088c3 100644
--- a/lotuswordpro/source/filter/lwplayoutdef.hxx
+++ b/lotuswordpro/source/filter/lwplayoutdef.hxx
@@ -101,7 +101,7 @@
 #define STYLE2_PROTECTED            0x20UL
 #define STYLE2_ACCESSRIGHTS         0x30UL
 #define STYLE2_HONORPROTECTION      0x40UL
-#define STYLE2_CHILDSPANNABLE       0x80UL
+#define STYLE2_CHILDSPANNABLE       0x80UL
 #define STYLE2_DEACTIVATED          0x200UL
 #define STYLE2_NOCONTENTREFERENCE   0x400UL
 #define STYLE2_ADOPTED              0x800UL
diff --git a/rsc/doku/feinkonz.43/rsc.sdw b/rsc/doku/feinkonz.43/rsc.sdw
index fb9214668c506fbcf6fa1cc20480a45e159dc54e..1819990fb0e4e864ba7bcdecb10bf6517bd081fa 100644
GIT binary patch
delta 18
acmdnHlXd@2)(u&InS)&YHfR40iU$Byya>bq

delta 16
YcmdnLlXdS-)(u&I8G|?H{tb!;07pRxG5`Po

diff --git a/svtools/inc/svtools/svlbox.hxx b/svtools/inc/svtools/svlbox.hxx
index 65cbe3e..b246854 100644
--- a/svtools/inc/svtools/svlbox.hxx
+++ b/svtools/inc/svtools/svlbox.hxx
@@ -172,7 +172,7 @@ public:
 };
 
 // Flags, die am Model haengen
-#define SV_ENTRYFLAG_CHILDS_ON_DEMAND   0x0001
+#define SV_ENTRYFLAG_CHILDREN_ON_DEMAND   0x0001
 #define SV_ENTRYFLAG_DISABLE_DROP       0x0002
 #define SV_ENTRYFLAG_IN_USE             0x0004
 // wird gesetzt, wenn RequestingChildren keine Children gestzt hat
@@ -209,7 +209,7 @@ public:
     void        SetUserData( void* pPtr ) { pUserData = pPtr; }
     virtual void Clone( SvListEntry* pSource );
     void        EnableChildrenOnDemand( sal_Bool bEnable=sal_True );
-    sal_Bool        HasChildrenOnDemand() const { return (sal_Bool)((nEntryFlags & 
SV_ENTRYFLAG_CHILDS_ON_DEMAND)!=0); }
+    sal_Bool        HasChildrenOnDemand() const { return (sal_Bool)((nEntryFlags & 
SV_ENTRYFLAG_CHILDREN_ON_DEMAND)!=0); }
     sal_Bool        HasInUseEmphasis() const    { return (sal_Bool)((nEntryFlags & 
SV_ENTRYFLAG_IN_USE)!=0); }
 
     sal_uInt16      GetFlags() const { return nEntryFlags; }
@@ -508,7 +508,7 @@ public:
     SvLBoxItem*     GetHdlItem() const;
 
     // wird aufgerufen, wenn ein Eintrag mit gesetztem
-    // ENTRYFLAG_CHILDS_ON_DEMAND expandiert wird.
+    // ENTRYFLAG_CHILDREN_ON_DEMAND expandiert wird.
     virtual void RequestingChildren( SvLBoxEntry* pParent );
 
     // Drag & Drop
diff --git a/svtools/source/contnr/svlbox.cxx b/svtools/source/contnr/svlbox.cxx
index 7eea319..3626e61 100644
--- a/svtools/source/contnr/svlbox.cxx
+++ b/svtools/source/contnr/svlbox.cxx
@@ -621,9 +621,9 @@ void SvLBoxEntry::EnableChildrenOnDemand( sal_Bool bEnable )
 {
     DBG_CHKTHIS(SvLBoxEntry,0);
     if ( bEnable )
-        nEntryFlags |= SV_ENTRYFLAG_CHILDS_ON_DEMAND;
+        nEntryFlags |= SV_ENTRYFLAG_CHILDREN_ON_DEMAND;
     else
-        nEntryFlags &= (~SV_ENTRYFLAG_CHILDS_ON_DEMAND);
+        nEntryFlags &= (~SV_ENTRYFLAG_CHILDREN_ON_DEMAND);
 }
 
 void SvLBoxEntry::ReplaceItem( SvLBoxItem* pNewItem, sal_uInt16 nPos )
diff --git a/svx/source/accessibility/svxrectctaccessiblecontext.cxx 
b/svx/source/accessibility/svxrectctaccessiblecontext.cxx
index f8729ef..515a0ec 100644
--- a/svx/source/accessibility/svxrectctaccessiblecontext.cxx
+++ b/svx/source/accessibility/svxrectctaccessiblecontext.cxx
@@ -57,8 +57,8 @@ using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::accessibility;
 
 
-#define MAX_NUM_OF_CHILDS   9
-#define NOCHILDSELECTED     -1
+#define MAX_NUM_OF_CHILDREN   9
+#define NOCHILDSELECTED     -1
 
 
 DBG_NAME( SvxRectCtlAccessibleContext )
@@ -124,7 +124,7 @@ static long PointToIndex( RECT_POINT ePoint, sal_Bool bAngleControl )
             case RP_MT: nRet = 2;               break;
             case RP_RT: nRet = 1;               break;
             case RP_LM: nRet = 4;               break;
-            case RP_MM: nRet = NOCHILDSELECTED; break;
+            case RP_MM: nRet = NOCHILDSELECTED; break;
             case RP_RM: nRet = 0;               break;
             case RP_LB: nRet = 5;               break;
             case RP_MB: nRet = 6;               break;
@@ -155,7 +155,7 @@ SvxRectCtlAccessibleContext::SvxRectCtlAccessibleContext(
     mpRepr( &rRepr ),
     mpChildren( NULL ),
     mnClientId( 0 ),
-    mnSelectedChild( NOCHILDSELECTED ),
+    mnSelectedChild( NOCHILDSELECTED ),
     mbAngleMode( rRepr.GetNumOfChildren() == 8 )
 {
     DBG_CTOR( SvxRectCtlAccessibleContext, NULL );
@@ -176,10 +176,10 @@ SvxRectCtlAccessibleContext::SvxRectCtlAccessibleContext(
         msDescription = SVX_RESSTR( mbAngleMode? RID_SVXSTR_RECTCTL_ACC_ANGL_DESCR : 
RID_SVXSTR_RECTCTL_ACC_CORN_DESCR );
     }
 
-    mpChildren = new SvxRectCtlChildAccessibleContext*[ MAX_NUM_OF_CHILDS ];
+    mpChildren = new SvxRectCtlChildAccessibleContext*[ MAX_NUM_OF_CHILDREN ];
 
     SvxRectCtlChildAccessibleContext**  p = mpChildren;
-    for( int i = MAX_NUM_OF_CHILDS ; i ; --i, ++p )
+    for( int i = MAX_NUM_OF_CHILDREN ; i ; --i, ++p )
         *p = NULL;
 }
 
@@ -221,7 +221,7 @@ Reference< XAccessible > SAL_CALL SvxRectCtlAccessibleContext::getAccessibleAtPo
 
     long                        nChild = PointToIndex( mpRepr->GetApproxRPFromPixPt( rPoint ), 
mbAngleMode );
 
-    if( nChild != NOCHILDSELECTED )
+    if( nChild != NOCHILDSELECTED )
         xRet = getAccessibleChild( nChild );
 
     return xRet;
@@ -598,7 +598,7 @@ sal_Int32 SAL_CALL SvxRectCtlAccessibleContext::getSelectedAccessibleChildCount(
 {
     ::osl::MutexGuard   aGuard( m_aMutex );
 
-    return mnSelectedChild == NOCHILDSELECTED? 0 : 1;
+    return mnSelectedChild == NOCHILDSELECTED? 0 : 1;
 }
 
 Reference< XAccessible > SAL_CALL SvxRectCtlAccessibleContext::getSelectedAccessibleChild( 
sal_Int32 nIndex )
@@ -630,7 +630,7 @@ void SvxRectCtlAccessibleContext::checkChildIndex( long nIndex ) throw( lang::In
 
 void SvxRectCtlAccessibleContext::checkChildIndexOnSelection( long nIndex ) throw( 
lang::IndexOutOfBoundsException )
 {
-    if( nIndex || mnSelectedChild == NOCHILDSELECTED )
+    if( nIndex || mnSelectedChild == NOCHILDSELECTED )
         // in our case only for the first (0) _selected_ child this is a valid request
         throw lang::IndexOutOfBoundsException();
 }
@@ -644,7 +644,7 @@ void SvxRectCtlAccessibleContext::selectChild( long nNew )
         if( nNew < nNumOfChildren )
         {   // valid index
             SvxRectCtlChildAccessibleContext*   pChild;
-            if( mnSelectedChild != NOCHILDSELECTED )
+            if( mnSelectedChild != NOCHILDSELECTED )
             {   // deselect old selected child if one is selected
                 pChild = mpChildren[ mnSelectedChild ];
                 if( pChild )
@@ -654,7 +654,7 @@ void SvxRectCtlAccessibleContext::selectChild( long nNew )
             // select new child
             mnSelectedChild = nNew;
 
-            if( nNew != NOCHILDSELECTED )
+            if( nNew != NOCHILDSELECTED )
             {
                 pChild = mpChildren[ nNew ];
                 if( pChild )
@@ -662,7 +662,7 @@ void SvxRectCtlAccessibleContext::selectChild( long nNew )
             }
         }
         else
-            mnSelectedChild = NOCHILDSELECTED;
+            mnSelectedChild = NOCHILDSELECTED;
     }
 }
 
@@ -719,7 +719,7 @@ void SAL_CALL SvxRectCtlAccessibleContext::disposing()
             mpRepr = NULL;      // object dies with representation
 
             SvxRectCtlChildAccessibleContext**  p = mpChildren;
-            for( int i = MAX_NUM_OF_CHILDS ; i ; --i, ++p )
+            for( int i = MAX_NUM_OF_CHILDREN ; i ; --i, ++p )
             {
                 SvxRectCtlChildAccessibleContext*   pChild = *p;
                 if( pChild )
diff --git a/svx/source/inc/svxrectctaccessiblecontext.hxx 
b/svx/source/inc/svxrectctaccessiblecontext.hxx
index d5dd920..fa9dff4 100644
--- a/svx/source/inc/svxrectctaccessiblecontext.hxx
+++ b/svx/source/inc/svxrectctaccessiblecontext.hxx
@@ -247,7 +247,7 @@ protected:
     /** Selects a new child by index.
 
         <p>If the child was not selected before, the state of the child will
-        be updated. If the index is invalid, the index will internaly set to NOCHILDSELECTED</p>
+        be updated. If the index is invalid, the index will internaly set to NOCHILDSELECTED</p>
 
         @param nIndexOfChild
             Index of the new child which should be selected.
@@ -258,7 +258,7 @@ public:
     /** Selects a new child by point.
 
         <p>If the child was not selected before, the state of the child will
-        be updated. If the point is not invalid, the index will internaly set to 
NOCHILDSELECTED</p>
+        be updated. If the point is not invalid, the index will internaly set to 
NOCHILDSELECTED</p>
 
         @param eButton
             Button which belongs to the child which should be selected.
diff --git a/vcl/source/window/window.cxx b/vcl/source/window/window.cxx
index 98611d1..93de162 100644
--- a/vcl/source/window/window.cxx
+++ b/vcl/source/window/window.cxx
@@ -119,8 +119,8 @@ DBG_NAME( Window )
 
 #define IMPL_PAINT_PAINT            ((sal_uInt16)0x0001)
 #define IMPL_PAINT_PAINTALL         ((sal_uInt16)0x0002)
-#define IMPL_PAINT_PAINTALLCHILDS   ((sal_uInt16)0x0004)
-#define IMPL_PAINT_PAINTCHILDS      ((sal_uInt16)0x0008)
+#define IMPL_PAINT_PAINTALLCHILDREN   ((sal_uInt16)0x0004)
+#define IMPL_PAINT_PAINTCHILDREN      ((sal_uInt16)0x0008)
 #define IMPL_PAINT_ERASE            ((sal_uInt16)0x0010)
 #define IMPL_PAINT_CHECKRTL         ((sal_uInt16)0x0020)
 
@@ -2329,16 +2329,16 @@ void Window::ImplCallPaint( const Region* pRegion, sal_uInt16 nPaintFlags )
 
     mpWindowImpl->mbPaintFrame = sal_False;
 
-    if ( nPaintFlags & IMPL_PAINT_PAINTALLCHILDS )
-        mpWindowImpl->mnPaintFlags |= IMPL_PAINT_PAINT | IMPL_PAINT_PAINTALLCHILDS | (nPaintFlags 
& IMPL_PAINT_PAINTALL);
-    if ( nPaintFlags & IMPL_PAINT_PAINTCHILDS )
-        mpWindowImpl->mnPaintFlags |= IMPL_PAINT_PAINTCHILDS;
+    if ( nPaintFlags & IMPL_PAINT_PAINTALLCHILDREN )
+        mpWindowImpl->mnPaintFlags |= IMPL_PAINT_PAINT | IMPL_PAINT_PAINTALLCHILDREN | 
(nPaintFlags & IMPL_PAINT_PAINTALL);
+    if ( nPaintFlags & IMPL_PAINT_PAINTCHILDREN )
+        mpWindowImpl->mnPaintFlags |= IMPL_PAINT_PAINTCHILDREN;
     if ( nPaintFlags & IMPL_PAINT_ERASE )
         mpWindowImpl->mnPaintFlags |= IMPL_PAINT_ERASE;
     if ( nPaintFlags & IMPL_PAINT_CHECKRTL )
         mpWindowImpl->mnPaintFlags |= IMPL_PAINT_CHECKRTL;
     if ( !mpWindowImpl->mpFirstChild )
-        mpWindowImpl->mnPaintFlags &= ~IMPL_PAINT_PAINTALLCHILDS;
+        mpWindowImpl->mnPaintFlags &= ~IMPL_PAINT_PAINTALLCHILDREN;
 
     if ( mpWindowImpl->mbPaintDisabled )
     {
@@ -2371,7 +2371,7 @@ void Window::ImplCallPaint( const Region* pRegion, sal_uInt16 nPaintFlags )
                */
                 mpWindowImpl->maInvalidateRegion.Union( *mpWindowImpl->mpWinData->mpTrackRect );
 
-            if ( mpWindowImpl->mnPaintFlags & IMPL_PAINT_PAINTALLCHILDS )
+            if ( mpWindowImpl->mnPaintFlags & IMPL_PAINT_PAINTALLCHILDREN )
                 pChildRegion = new Region( mpWindowImpl->maInvalidateRegion );
             mpWindowImpl->maInvalidateRegion.Intersect( *pWinChildClipRegion );
         }
@@ -2433,7 +2433,7 @@ void Window::ImplCallPaint( const Region* pRegion, sal_uInt16 nPaintFlags )
     else
         mpWindowImpl->mnPaintFlags = 0;
 
-    if ( nPaintFlags & (IMPL_PAINT_PAINTALLCHILDS | IMPL_PAINT_PAINTCHILDS) )
+    if ( nPaintFlags & (IMPL_PAINT_PAINTALLCHILDREN | IMPL_PAINT_PAINTCHILDREN) )
     {
         // Paint from the bottom child window and frontward.
         Window* pTempWindow = mpWindowImpl->mpLastChild;
@@ -2472,7 +2472,7 @@ void Window::ImplCallOverlapPaint()
     }
 
     // only then ourself
-    if ( mpWindowImpl->mnPaintFlags & (IMPL_PAINT_PAINT | IMPL_PAINT_PAINTCHILDS) )
+    if ( mpWindowImpl->mnPaintFlags & (IMPL_PAINT_PAINT | IMPL_PAINT_PAINTCHILDREN) )
     {
         // - RTL - notify ImplCallPaint to check for re-mirroring (CHECKRTL)
         //         because we were called from the Sal layer
@@ -2521,7 +2521,7 @@ IMPL_LINK( Window, ImplHandleResizeTimerHdl, void*, EMPTYARG )
 
 void Window::ImplInvalidateFrameRegion( const Region* pRegion, sal_uInt16 nFlags )
 {
     // set PAINTCHILDS for all parent windows till the first OverlapWindow
     if ( !ImplIsOverlapWindow() )
     {
         Window* pTempWindow = this;
@@ -2529,9 +2529,9 @@ void Window::ImplInvalidateFrameRegion( const Region* pRegion, sal_uInt16 
nFlags
         do
         {
             pTempWindow = pTempWindow->ImplGetParent();
-            if ( pTempWindow->mpWindowImpl->mnPaintFlags & IMPL_PAINT_PAINTCHILDS )
+            if ( pTempWindow->mpWindowImpl->mnPaintFlags & IMPL_PAINT_PAINTCHILDREN )
                 break;
-            pTempWindow->mpWindowImpl->mnPaintFlags |= IMPL_PAINT_PAINTCHILDS | nTranspPaint;
+            pTempWindow->mpWindowImpl->mnPaintFlags |= IMPL_PAINT_PAINTCHILDREN | nTranspPaint;
             if( ! pTempWindow->IsPaintTransparent() )
                 nTranspPaint = 0;
         }
@@ -2541,7 +2541,7 @@ void Window::ImplInvalidateFrameRegion( const Region* pRegion, sal_uInt16 
nFlags
     // set Paint-Flags
     mpWindowImpl->mnPaintFlags |= IMPL_PAINT_PAINT;
     if ( nFlags & INVALIDATE_CHILDREN )
-        mpWindowImpl->mnPaintFlags |= IMPL_PAINT_PAINTALLCHILDS;
+        mpWindowImpl->mnPaintFlags |= IMPL_PAINT_PAINTALLCHILDREN;
     if ( !(nFlags & INVALIDATE_NOERASE) )
         mpWindowImpl->mnPaintFlags |= IMPL_PAINT_ERASE;
     if ( !pRegion )
@@ -2710,7 +2710,7 @@ void Window::ImplMoveInvalidateRegion( const Rectangle& rRect,
         mpWindowImpl->maInvalidateRegion.Union( aTempRegion );
     }
 
-    if ( bChildren && (mpWindowImpl->mnPaintFlags & IMPL_PAINT_PAINTCHILDS) )
+    if ( bChildren && (mpWindowImpl->mnPaintFlags & IMPL_PAINT_PAINTCHILDREN) )
     {
         Window* pWindow = mpWindowImpl->mpFirstChild;
         while ( pWindow )
@@ -2737,7 +2737,7 @@ void Window::ImplMoveAllInvalidateRegions( const Rectangle& rRect,
         do
         {
             pPaintAllWindow = pPaintAllWindow->ImplGetParent();
-            if ( pPaintAllWindow->mpWindowImpl->mnPaintFlags & IMPL_PAINT_PAINTALLCHILDS )
+            if ( pPaintAllWindow->mpWindowImpl->mnPaintFlags & IMPL_PAINT_PAINTALLCHILDREN )
             {
                 if ( pPaintAllWindow->mpWindowImpl->mnPaintFlags & IMPL_PAINT_PAINTALL )
                 {
@@ -2769,7 +2769,7 @@ void Window::ImplValidateFrameRegion( const Region* pRegion, sal_uInt16 
nFlags )
     else
     {
         // when all child windows have to be drawn we need to invalidate them before doing so
-        if ( (mpWindowImpl->mnPaintFlags & IMPL_PAINT_PAINTALLCHILDS) && 
mpWindowImpl->mpFirstChild )
+        if ( (mpWindowImpl->mnPaintFlags & IMPL_PAINT_PAINTALLCHILDREN) && 
mpWindowImpl->mpFirstChild )
         {
             Region aChildRegion = mpWindowImpl->maInvalidateRegion;
             if ( mpWindowImpl->mnPaintFlags & IMPL_PAINT_PAINTALL )
@@ -3038,7 +3038,7 @@ void Window::ImplUpdateAll( sal_Bool bOverlapWindows )
         pWindow->ImplCallOverlapPaint();
     else
     {
-        if ( pWindow->mpWindowImpl->mnPaintFlags & (IMPL_PAINT_PAINT | IMPL_PAINT_PAINTCHILDS) )
+        if ( pWindow->mpWindowImpl->mnPaintFlags & (IMPL_PAINT_PAINT | IMPL_PAINT_PAINTCHILDREN) )
             pWindow->ImplCallPaint( NULL, pWindow->mpWindowImpl->mnPaintFlags );
     }
 
@@ -7379,7 +7379,7 @@ sal_Bool Window::HasPaintEvent() const
         do
         {
             pTempWindow = pTempWindow->ImplGetParent();
-            if ( pTempWindow->mpWindowImpl->mnPaintFlags & (IMPL_PAINT_PAINTCHILDS | 
IMPL_PAINT_PAINTALLCHILDS) )
+            if ( pTempWindow->mpWindowImpl->mnPaintFlags & (IMPL_PAINT_PAINTCHILDREN | 
IMPL_PAINT_PAINTALLCHILDREN) )
                 return sal_True;
         }
         while ( !pTempWindow->ImplIsOverlapWindow() );
@@ -7426,11 +7426,11 @@ void Window::Update()
         pWindow = pWindow->ImplGetParent();
     }
     // In order to limit drawing, an update only draws the window which
-    // has PAINTALLCHILDS set
+    // has PAINTALLCHILDREN set
     pWindow = pUpdateWindow;
     do
     {
-        if ( pWindow->mpWindowImpl->mnPaintFlags & IMPL_PAINT_PAINTALLCHILDS )
+        if ( pWindow->mpWindowImpl->mnPaintFlags & IMPL_PAINT_PAINTALLCHILDREN )
             pUpdateWindow = pWindow;
         if ( pWindow->ImplIsOverlapWindow() )
             break;
@@ -7439,7 +7439,7 @@ void Window::Update()
     while ( pWindow );
 
     // if there is something to paint, trigger a Paint
-    if ( pUpdateWindow->mpWindowImpl->mnPaintFlags & (IMPL_PAINT_PAINT | IMPL_PAINT_PAINTCHILDS) )
+    if ( pUpdateWindow->mpWindowImpl->mnPaintFlags & (IMPL_PAINT_PAINT | IMPL_PAINT_PAINTCHILDREN) 
)
     {
         // trigger an update also for system windows on top of us,
@@ -2521,7 +2521,7 @@ IMPL_LINK( Window, ImplHandleResizeTimerHdl, void*, EMPTYARG )
 void Window::ImplInvalidateFrameRegion( const Region* pRegion, sal_uInt16 nFlags )
 {
-    // set PAINTCHILDS for all parent windows till the first OverlapWindow
+    // set PAINTCHILDREN for all parent windows till the first OverlapWindow
     if ( !ImplIsOverlapWindow() )
     {
         // otherwise holes would remain
-- 
1.7.3.2


Context


Privacy Policy | Impressum (Legal Info) | Copyright information: Unless otherwise specified, all text and images on this website are licensed under the Creative Commons Attribution-Share Alike 3.0 License. This does not include the source code of LibreOffice, which is licensed under the Mozilla Public License (MPLv2). "LibreOffice" and "The Document Foundation" are registered trademarks of their corresponding registered owners or are in actual use as trademarks in one or more countries. Their respective logos and icons are also subject to international copyright laws. Use thereof is explained in our trademark policy.